@@ -60,12 +60,24 @@ PDB file (required for the creation of the dynamic Smotif library).
 # our ($PDB_DIR, $PDB_OBSOLETES);
 our $PDB_DIR;
 our $PDB_OBSOLETES;
+our $USER_SPECIFIC_PDB_PATH;
 
 use Data::Dumper;
-use constant DSSP_PATH => "/usr/local/bin";
-use constant DSSP_EXEC => "dsspcmbi";
+use Carp;
+#use constant DSSP_PATH => "/usr/local/bin";
+#use constant DSSP_EXEC => "dsspcmbi";
 use constant DISTANCE  => 4.3;
 
+my $config_file = $ENV{'SMOTIFTF_CONFIG_FILE'};
+croak "Environmental variable SMOTIFTF_CONFIG_FILE should be set"
+    unless $config_file;
+
+my $cfg           = new Config::Simple($config_file);
+my $dssp      = $cfg->param( -block => 'dssp' );
+my $DSSP_PATH = $dssp->{'path'};
+my $DSSP_EXEC = $dssp->{'exec'};
+
+
 # LOAD WILMOT-THORTON PHI-PSI SPACE PARTITION
 my %ramareduced  = read_rama_reduced();
 my %ramaextended = read_rama_extended();
@@ -87,6 +99,7 @@ sub extract_loops {
     use SmotifTF::PDB::PDBfileParser qw(ParsePDBfile locate_pdb_file);
     $PDB::PDBfileParser::PDB_DIR       = $PDB_DIR;
     $PDB::PDBfileParser::PDB_OBSOLETES = $PDB_OBSOLETES;
+	$PDB::PDBfileParser::USER_SPECIFIC_PDB_PATH = $USER_SPECIFIC_PDB_PATH;
 
     #use lib "/usr/local/lib/perl/VILAS/";
     use SmotifTF::GeometricMeasurements qw(recalc);
@@ -133,7 +146,7 @@ sub extract_loops {
     my $dsspoutput = $pdb_code . $chain . '.dssp.out';
 
     my $cmd =
-      DSSP_PATH . "/" . DSSP_EXEC . " $temppdb $tempdssp > $dsspoutput 2>&1";
+      $DSSP_PATH . "/" . $DSSP_EXEC . " $temppdb $tempdssp > $dsspoutput 2>&1";
     system($cmd );
 
 # EXTRACT LOOPS FROM DSSP FILE + PHI/PSI ANGLES -> ASSIGN RAMA. CONF (REDUCED+EXTENDED);
@@ -144,15 +157,17 @@ sub extract_loops {
     # extract_SSS
     # parse ddsp to get Smotifs from the structure
     unless ($num_extracted) {
+		delete_dssp_tmp_files($pdb_code, $chain);
         die "No valid loop motifs in this pdb file";
     }
 
     #GEOMETRIES - RAMA PRINT
     my $uploadpdbfull = SmotifTF::PDB::PDBfileParser::locate_pdb_file(
-        pdb_obsoletes_path => $PDB_OBSOLETES,
-        pdb_path           => $PDB_DIR,
-        pdb_code           => $pdb_code,
-        chain              => $chain,
+        pdb_obsoletes_path     => $PDB_OBSOLETES,
+        pdb_path               => $PDB_DIR,
+		user_specific_pdb_path => $USER_SPECIFIC_PDB_PATH,
+        pdb_code               => $pdb_code,
+        chain                  => $chain,
     );
     
     $uploadpdbfull = basename($uploadpdbfull);
@@ -164,7 +179,8 @@ sub extract_loops {
         my @smotiffields = split /\s+/, $extracted;
         unless ( scalar(@smotiffields) == 14 ) {
             print "unexpected splitting results of extracted smotif\n\t$extracted\n";
-            print Dumper ( \@smotiffields );
+            #print Dumper ( \@smotiffields );
+            delete_dssp_tmp_files($pdb_code, $chain);
             die
               "unexpected splitting results of extracted smotif\n\t$extracted";
             return;
@@ -199,15 +215,7 @@ sub extract_loops {
 
     }    #end foreach loop
 
-    if ( -e $temppdb ) {
-        unlink($temppdb) or die "can't delete $temppdb\n";
-    }
-    if ( -e $tempdssp ) {
-        unlink($tempdssp) or die "can't delete $tempdssp\n";
-    }
-    if ( -e $dsspoutput ) {
-        unlink($dsspoutput) or die "can't delete $dsspoutput\n";
-    }
+	delete_dssp_tmp_files($pdb_code, $chain);
 
     return @finals;
 
@@ -219,6 +227,7 @@ sub missing_residues {
     use SmotifTF::PDB::PDBfileParser qw(ParsePDBfile);
     $PDB::PDBfileParser::PDB_DIR       = $PDB_DIR;
     $PDB::PDBfileParser::PDB_OBSOLETES = $PDB_OBSOLETES;
+	$PDB::PDBfileParser::USER_SPECIFIC_PDB_PATH = $USER_SPECIFIC_PDB_PATH;
 
     #my $name = (caller(1))[3];
     #print "missing_residues $name $PDB_DIR\n";
@@ -265,7 +274,7 @@ sub missing_residues {
     my $dsspoutput = $pdb_code . $chain . '.dssp.out';
 
     my $cmd =
-      DSSP_PATH . "/" . DSSP_EXEC . " $temppdb $tempdssp > $dsspoutput 2>&1";
+      $DSSP_PATH . "/" . $DSSP_EXEC . " $temppdb $tempdssp > $dsspoutput 2>&1";
     system($cmd );
     print "CMD=$cmd\n";
 
@@ -274,15 +283,7 @@ sub missing_residues {
     my ( $missing_residue, $num_extracted, @extracted ) =
       extract_SSS( $tempdssp, $chain, $ArrayRef_coordchain, $pdb_code );
 
-    if ( -e $temppdb ) {
-        unlink($temppdb) or die "can't delete $temppdb\n";
-    }
-    if ( -e $tempdssp ) {
-        unlink($tempdssp) or die "can't delete $tempdssp\n";
-    }
-    if ( -e $dsspoutput ) {
-        unlink($dsspoutput) or die "can't delete $dsspoutput\n";
-    }
+	delete_dssp_tmp_files($pdb_code, $chain);
 
     # extract_SSS
     # parse ddsp to get Smotifs from the structure
@@ -533,6 +534,27 @@ sub check_pdb_file {
     return ($retcheck);
 }
 
+sub delete_dssp_tmp_files {
+
+	my ($pdb_code, $chain) = @_;
+
+	my $temppdb    = $pdb_code . $chain . '.pdb';
+    my $tempdssp   = $pdb_code . $chain . '.dssp';
+    my $dsspoutput = $pdb_code . $chain . '.dssp.out';
+
+
+   if ( -e $temppdb ) {
+        unlink($temppdb) or croak "can't delete $temppdb";
+    }    
+    if ( -e $tempdssp ) {
+        unlink($tempdssp) or croak "can't delete $tempdssp";
+    }    
+    if ( -e $dsspoutput ) {
+        unlink($dsspoutput) or croak "can't delete $dsspoutput";
+    } 
+
+}
+
 ###########################
 ##### CHECKED
 sub extract_SSS {
@@ -549,6 +571,7 @@ sub extract_SSS {
     my $rettrue = 0;
 
     unless ( -e $tempdssp ) { 
+	delete_dssp_tmp_files ($uploadpdb, $uploadchain);
 	die " There was error: $tempdssp does not exist for $uploadpdb\t$uploadchain"; 
    }
 
@@ -603,6 +626,7 @@ sub extract_SSS {
               )
             {
                 print "$uploadpdb\t$uploadchain\t unexpected amino acid type\n\t$lrestype\n";
+				delete_dssp_tmp_files ($uploadpdb, $uploadchain);
                 die "There was error: $uploadpdb\t$uploadchain\t unexpected amino acid type\n\t$lrestype";
                 
             }
@@ -613,6 +637,7 @@ sub extract_SSS {
             if ( $lss eq '' ) { $lss = "C"; }
             unless ( $lss =~ /^[H_B_E_G_I_T_S_C]$/ ) {
                 print "$uploadpdb\t$uploadchain\t unexpected ss type\n\t$lss\n";
+				delete_dssp_tmp_files ($uploadpdb, $uploadchain);
                 die "There was error: $uploadpdb\t$uploadchain\t unexpected ss type\n\t$lss";
                 
             }
@@ -636,6 +661,7 @@ sub extract_SSS {
             }
             else {
                 print "$uploadpdb\t$uploadchain\t unexpected DSSP secondary structure type\t$lss\n";
+				delete_dssp_tmp_files ($uploadpdb, $uploadchain);
                 die "There was error: $uploadpdb\t$uploadchain\t unexpected DSSP secondary structure type\t$lss";
                 
             }
@@ -643,6 +669,7 @@ sub extract_SSS {
             #get phi and psi values for current residue
             my $lphi = substr( $dsspline, 103, 6 );
             unless ( defined($lphi) ) {
+				delete_dssp_tmp_files ($uploadpdb, $uploadchain);
                 die "There was error: $uploadpdb\t$uploadchain\t lphi not defined\t$lphi";
             }
             $lphi =~ s/\s+//g;
@@ -650,6 +677,7 @@ sub extract_SSS {
             my $lpsi = substr( $dsspline, 109, 6 );
             unless ( defined($lpsi) ) {
                 print "$uploadpdb\t$uploadchain\t lphi not defined\t$lpsi\n";
+				delete_dssp_tmp_files ($uploadpdb, $uploadchain);
                 die "There was error: $uploadpdb\t$uploadchain\t lphi not defined\t$lpsi";
                 
             }
@@ -670,6 +698,7 @@ sub extract_SSS {
     }    #end DSSPLINE loop
     unless ( $start == 1 ) {
         print "error; never found dssp header line for $uploadpdb $uploadchain\n";
+		delete_dssp_tmp_files ($uploadpdb, $uploadchain);
         die "There was error: never found dssp header line for $uploadpdb $uploadchain";
         
     }
@@ -693,6 +722,7 @@ sub extract_SSS {
         my @temp_infoline = split /\t/, $infoline;
         unless ( scalar(@temp_infoline) == 5 ) {
             print "$uploadpdb\t$uploadchain\t unexpected residue,ss info\n\t$infoline\n";
+			delete_dssp_tmp_files ($uploadpdb, $uploadchain);
             die "There was error: $uploadpdb\t$uploadchain\t unexpected residue,ss info\n\t$infoline";
            
         }
@@ -792,6 +822,7 @@ sub extract_SSS {
         }
         else {
             print "$uploadpdb\t$uploadchain\t H/E/C logic\n";
+			delete_dssp_tmp_files ($uploadpdb, $uploadchain);
             die "There was error: $uploadpdb\t$uploadchain\t H/E/C logic";
            # return;
         }    #end "H" or "E" if/else logic
@@ -827,6 +858,7 @@ sub extract_SSS {
         }
         else {
             print "$uploadpdb\t$uploadchain\t LOGIC ERROR\n";
+			delete_dssp_tmp_files ($uploadpdb, $uploadchain);
             die "There was error: $uploadpdb\t$uploadchain\t LOGIC ERROR";
            # return;
         }
@@ -841,11 +873,13 @@ sub extract_SSS {
         my @temp_newline = split /\s+/, $newline;    #$temp[1]$temp[8]
         unless ( scalar(@temp_newline) ) {
             print "$uploadpdb\t$uploadchain\t unexpected combineline contents\n\t$newline\n";
+			delete_dssp_tmp_files ($uploadpdb, $uploadchain);
             die "There was error: $uploadpdb\t$uploadchain\t unexpected combineline contents\n\t$newline";
            # return;
         }
         unless ( exists $StartResKeyIDLookup{"$temp_newline[1]"} ) {
             print "$uploadpdb\t$uploadchain\t start residue does not exist in hash\n";
+			delete_dssp_tmp_files ($uploadpdb, $uploadchain);
             die "There was error: $uploadpdb\t$uploadchain\t start residue does not exist in hash";
            # return;
         }
@@ -854,6 +888,7 @@ sub extract_SSS {
         my $ss1ln    = $sslength{"$ss1keyid"};
         unless ( exists $StartResKeyIDLookup{"$temp_newline[4]"} ) {
             print "$uploadpdb\t$uploadchain\t start residue does not exist in hash\n";
+			delete_dssp_tmp_files ($uploadpdb, $uploadchain);
             die "There was error: $uploadpdb\t$uploadchain\t start residue does not exist in hash";
            # return;
         }
@@ -871,6 +906,7 @@ sub extract_SSS {
             my @temp2 = split /\s+/, $infoline;
             unless ( scalar(@temp2) == 5 ) {
                 print "$uploadpdb\t$uploadchain\t unexpected newline line\n\t$infoline\n";
+				delete_dssp_tmp_files ($uploadpdb, $uploadchain);
                 die "There was error: $uploadpdb\t$uploadchain\t unexpected newline line\n\t$infoline";
                # return;
             }
@@ -980,6 +1016,7 @@ sub extract_SSS {
             warn "$motif\t -> Discarded: loop length O\n";
         }
         else {
+			delete_dssp_tmp_files ($uploadpdb, $uploadchain);
             die "There was error: logic error in checkloop and checklength";
 
             # orginal code
