@@ -39,6 +39,22 @@ my $cfg           = new Config::Simple($config_file);
 my $localrun      = $cfg->param( -block => 'localrun' );
 my $MAX_PROCESSES = $localrun->{'max_proc'};
 
+my $dssp      = $cfg->param( -block => 'dssp' );
+my $DSSP_PATH = $dssp->{'path'};
+my $DSSP_EXEC = $dssp->{'exec'};
+
+my $pdb      = $cfg->param( -block => 'pdb' );
+my $PDB_DIR       = $pdb->{'uncompressed'};
+my $PDB_OBSOLETES = $pdb->{'obsoletes'};
+my $USER_SPECIFIC_PDB_PATH = $pdb->{'user_specific_pdb_path'};
+
+my $hhsuite          = $cfg->param( -block => 'hhsuite' );
+my $NR_HHM_DB        = $hhsuite->{'nr_hhm_db'};
+my $PDB_HHM_DB       = $hhsuite->{'pdb_hhm_db'};
+
+my $psiblast      = $cfg->param( -block => 'psiblast' );
+my $PDBAA_DB      = $psiblast->{'pdbaa_db'};
+
 my $sequence_file;
 my $step = 0;
 my $dir;
@@ -108,7 +124,7 @@ sub run_hhblits {
          SmotifTF::HHblits::run_hhblits(
                 sequence_fasta => $sequence_file,
                 directory => $dir,
-                database  => 'nr20_12Aug11',
+                database  => $NR_HHM_DB,
                 oa3m      => $oa3m,
                 ohhm      => $ohhm,
         );
@@ -136,7 +152,7 @@ sub run_hhsearch {
         SmotifTF::HHblits::run_search(
                 sequence_hhm => $hhm,
                 directory => $dir,
-                database  => 'pdb70_06Sep14_hhm_db',
+                database  => $PDB_HHM_DB,
                 ohhr      => $hhr,
         );  
     };
@@ -156,7 +172,7 @@ sub run_psiblast {
         SmotifTF::Psiblast::run_psiblast(
             query          => $sequence_file,
             directory      => $dir, 
-            database       => 'pdbaa',
+            database       => $PDBAA_DB,
             out            => $psiblast_out,
             evalue         => 100,
             num_iterations => 2
@@ -178,7 +194,7 @@ sub run_deltablast {
         SmotifTF::Psiblast::run_deltablast(
             query          => $sequence_file,
             directory      => $dir, 
-            database       => 'pdbaa',
+            database       => $PDBAA_DB,
             out            => $deltablast_out,
             evalue         => 100,
         );
@@ -498,18 +514,14 @@ sub get_smotif_definition {
         use SmotifTF::GetSMotifsfromPDB qw(missing_residues extract_loops);
 
         # Directory that holds the pdb files to be parsed
-        # my $PDB_DIR       = "/usr/local/databases/pdb/uncompressed/";
 
-        my $PDB_DIR       = "/usr/local/databases/remodeled_pdb/";
-        my $PDB_OBSOLETES = "/usr/local/databases/remodeled_pdb/";
         $SmotifTF::GetSMotifsfromPDB::PDB_DIR       = $PDB_DIR;
         $SmotifTF::GetSMotifsfromPDB::PDB_OBSOLETES = $PDB_OBSOLETES;
+		$SmotifTF::GetSMotifsfromPDB::USER_SPECIFIC_PDB_PATH = $USER_SPECIFIC_PDB_PATH;
         
         $SmotifTF::PDB::PDBfileParser::PDB_DIR       = $PDB_DIR;
         $SmotifTF::PDB::PDBfileParser::PDB_OBSOLETES = $PDB_OBSOLETES;
-
-        use constant DSSP_PATH => "/usr/local/bin";
-        use constant DSSP_EXEC => "dsspcmbi";
+		$SmotifTF::PDB::PDBfileParser::USER_SPECIFIC_PDB_PATH = $USER_SPECIFIC_PDB_PATH;
 
         my ($full_path_name_file) = @_;
 
@@ -613,12 +625,26 @@ Software / data:
 
 4. Modeller (version 9.14 https://salilab.org/modeller/)
 
-5. Local PDB directory (central or user-designated) - updated (http://www.rcsb.org). 
+5. DSSP (http://swift.cmbi.ru.nl/gv/dssp/)
+
+6. Local PDB directory (central or user-designated from http://www.rcsb.org). Many PDB structures
+   are incomplete with missing residues. The SmotifTF algorithm performs best when the PDB 
+   structures are complete. Hence, we use Modeller (https://salilab.org/modeller/) to model the 
+   missing residues in the PDB to obtain complete structures. The algorithm can work with 
+   incomplete PDB structures but the performance may not be as expected. The SMotifTF software 
+   can handle gzipped (.gz) or unzipped (.ent) PDB structure files. 
+
+   The software for remodeling the missing residues can be obtained from our website at: 
+   http://fiserlab.org/remodel_pdb.tar.gz
+   This can be used to remodel missing residues in the entire PDB and these remodeled
+   structures can be used in the SmotifTF package. The SmotifTF package can handle both
+   regular and remodeled PDB database.
 
 Download and install the above mentioned software / data according to their instructions. 
 
-Note: Psipred and Psiblast require legacy blast and Delta-blast is a part of the Blast+ package. 
-
+Note: Psipred may require legacy blast and Psiblast and Delta-blast are part of the Blast+ package. 
+      .ncbirc file may be required in the home directory for Psipred. 
+    
 Databases required: 
 
 1. PDBAA blast database is required (ftp://ftp.ncbi.nlm.nih.gov/blast/db/). 
